==> jc-1.4.0.tar.gz: soot/jimple/parser/SkeletonExtractorWalker.h <==
// public class soot.jimple.parser.SkeletonExtractorWalker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 90847822417adfa5 soot_jimple_parser_SkeletonExtractorWalker
// @dep_class b8af2571138d5c8f soot_jimple_parser_Walker
// @dep_class b43a9165b67db951 soot_jimple_parser_analysis_AnalysisAdapter
// @dep_class 49cf7a14fc836e70 soot_jimple_parser_analysis_DepthFirstAdapter

// header file dependencies
// @dep_header soot_jimple_parser_Walker

#include "soot/jimple/parser/Walker.h"

#ifndef _JC_soot_jimple_parser_SkeletonExtractorWalker_H_
#define _JC_soot_jimple_parser_SkeletonExtractorWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootResolver$object;
struct _jc_soot_jimple_parser_node_AFile$object;
struct _jc_soot_jimple_parser_node_AMethodMember$object;
struct _jc_soot_jimple_parser_node_AThrowsClause$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs	_jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs	_jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$refs	_jc_soot_jimple_parser_SkeletonExtractorWalker$refs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs	_jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object	_jc_soot_jimple_parser_SkeletonExtractorWalker$object;

typedef const struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods	_jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods;
typedef const struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtable	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtable;
typedef const struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtype	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtype;

// Constructors
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$_init$f960fbcab686639c(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_SootResolver$object *);
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$_init$5ab2b392a0a53133(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_SootResolver$object *, struct _jc_soot_SootClass$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$caseAFile$b6916389b57c776a(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$caseAMethodMember$92ef21db736177c9(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *);
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$outAFile$453969294ea1f0d8(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$outAMethodMember$0fbbcd28a24c2ab7(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *);
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$outAThrowsClause$f6c785bc733b1680(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AThrowsClause$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$caseAFile$b6916389b57c776a;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$caseAMethodMember$92ef21db736177c9;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$outAFile$453969294ea1f0d8;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$outAMethodMember$0fbbcd28a24c2ab7;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$outAThrowsClause$f6c785bc733b1680;

// Virtual methods structure
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods {
	void	(*caseAFile$b6916389b57c776a)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
	void	(*caseAMethodMember$92ef21db736177c9)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *);
	void	(*outAFile$453969294ea1f0d8)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *);
	void	(*outAMethodMember$0fbbcd28a24c2ab7)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *);
	void	(*outAThrowsClause$f6c785bc733b1680)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AThrowsClause$object *);
};

// Vtable
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_analysis_AnalysisAdapter$vmethods	soot_jimple_parser_analysis_AnalysisAdapter;
	_jc_soot_jimple_parser_analysis_DepthFirstAdapter$vmethods	soot_jimple_parser_analysis_DepthFirstAdapter;
	_jc_soot_jimple_parser_Walker$vmethods	soot_jimple_parser_Walker;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods	soot_jimple_parser_SkeletonExtractorWalker;
};

// Vtype
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$refs {
    _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs	soot_jimple_parser_SkeletonExtractorWalker;
    _jc_soot_jimple_parser_Walker$sub_refs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_refs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_refs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_nonrefs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_nonrefs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_Walker$sub_nonrefs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs	soot_jimple_parser_SkeletonExtractorWalker;
};

// Object instance structure
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object {
	_jc_soot_jimple_parser_SkeletonExtractorWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtype	*vtype;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_SkeletonExtractorWalker$vtype _jc_soot_jimple_parser_SkeletonExtractorWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_SkeletonExtractorWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_SkeletonExtractorWalker$class_object;

#endif	/* _JC_soot_jimple_parser_SkeletonExtractorWalker_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/SkeletonExtractorWalker.h <==
// public class soot.jimple.parser.SkeletonExtractorWalker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 90847822417adfa5 soot_jimple_parser_SkeletonExtractorWalker
// @dep_class b8af2571138d5c8f soot_jimple_parser_Walker
// @dep_class b43a9165b67db951 soot_jimple_parser_analysis_AnalysisAdapter
// @dep_class 49cf7a14fc836e70 soot_jimple_parser_analysis_DepthFirstAdapter

// header file dependencies
// @dep_header soot_jimple_parser_Walker

#include "soot/jimple/parser/Walker.h"

#ifndef _JC_soot_jimple_parser_SkeletonExtractorWalker_H_
#define _JC_soot_jimple_parser_SkeletonExtractorWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootResolver$object;
struct _jc_soot_jimple_parser_node_AFile$object;
struct _jc_soot_jimple_parser_node_AMethodMember$object;
struct _jc_soot_jimple_parser_node_AThrowsClause$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs	_jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs	_jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$refs	_jc_soot_jimple_parser_SkeletonExtractorWalker$refs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs	_jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs;
typedef struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object	_jc_soot_jimple_parser_SkeletonExtractorWalker$object;

typedef const struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods	_jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods;
typedef const struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtable	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtable;
typedef const struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtype	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtype;

// Constructors
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$_init$f960fbcab686639c(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_SootResolver$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$_init$5ab2b392a0a53133(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_SootResolver$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$caseAFile$b6916389b57c776a(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$caseAMethodMember$92ef21db736177c9(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$outAFile$453969294ea1f0d8(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$outAMethodMember$0fbbcd28a24c2ab7(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_SkeletonExtractorWalker$method$outAThrowsClause$f6c785bc733b1680(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AThrowsClause$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$caseAFile$b6916389b57c776a;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$caseAMethodMember$92ef21db736177c9;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$outAFile$453969294ea1f0d8;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$outAMethodMember$0fbbcd28a24c2ab7;
extern _jc_method _jc_soot_jimple_parser_SkeletonExtractorWalker$method_info$outAThrowsClause$f6c785bc733b1680;

// Virtual methods structure
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods {
	void	(*caseAFile$b6916389b57c776a)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
	void	(*caseAMethodMember$92ef21db736177c9)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *) _JC_JCNI_ATTR;
	void	(*outAFile$453969294ea1f0d8)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFile$object *) _JC_JCNI_ATTR;
	void	(*outAMethodMember$0fbbcd28a24c2ab7)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AMethodMember$object *) _JC_JCNI_ATTR;
	void	(*outAThrowsClause$f6c785bc733b1680)(_jc_env *, struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AThrowsClause$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_analysis_AnalysisAdapter$vmethods	soot_jimple_parser_analysis_AnalysisAdapter;
	_jc_soot_jimple_parser_analysis_DepthFirstAdapter$vmethods	soot_jimple_parser_analysis_DepthFirstAdapter;
	_jc_soot_jimple_parser_Walker$vmethods	soot_jimple_parser_Walker;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$vmethods	soot_jimple_parser_SkeletonExtractorWalker;
};

// Vtype
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$refs {
    _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_refs	soot_jimple_parser_SkeletonExtractorWalker;
    _jc_soot_jimple_parser_Walker$sub_refs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_refs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_refs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_nonrefs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_nonrefs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_Walker$sub_nonrefs	soot_jimple_parser_Walker;
    _jc_soot_jimple_parser_SkeletonExtractorWalker$sub_nonrefs	soot_jimple_parser_SkeletonExtractorWalker;
};

// Object instance structure
struct _jc_soot_jimple_parser_SkeletonExtractorWalker$object {
	_jc_soot_jimple_parser_SkeletonExtractorWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$vtype	*vtype;
	_jc_soot_jimple_parser_SkeletonExtractorWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_SkeletonExtractorWalker$vtype _jc_soot_jimple_parser_SkeletonExtractorWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_SkeletonExtractorWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_SkeletonExtractorWalker$class_object;

#endif	/* _JC_soot_jimple_parser_SkeletonExtractorWalker_H_ */
